@@ -256,13 +256,13 @@ Zoom(Window wf, Window wt)
  *  \param name  the filename to expand
  */
 char *
-ExpandFilename(char *name)
+ExpandFilename(const char *name)
 {
     char *newname;
 
-    if (name[0] != '~') return name;
+    if (name[0] != '~') return strdup(name);
 
-    newname = (char *) malloc (HomeLen + strlen(name) + 2);
+    newname = malloc (HomeLen + strlen(name) + 2);
     if (!newname) {
 	fprintf (stderr,
 		 "%s:  unable to allocate %ld bytes to expand filename %s/%s\n",
@@ -281,7 +281,7 @@ ExpandFilename(char *name)
  * \param name  the filename to read
  */
 void
-GetUnknownIcon(char *name)
+GetUnknownIcon(const char *name)
 {
     if ((Scr->UnknownPm = GetBitmap(name)) != None)
     {
@@ -300,7 +300,7 @@ GetUnknownIcon(char *name)
  *  \param[out] heightp	 pointer to height of bitmap
  */
 Pixmap
-FindBitmap (char *name, unsigned *widthp, unsigned *heightp)
+FindBitmap (const char *name, unsigned *widthp, unsigned *heightp)
 {
     char *bigname;
     Pixmap pm;
@@ -315,7 +315,7 @@ FindBitmap (char *name, unsigned *widthp, unsigned *heightp)
     if (name[0] == ':') {
 	int i;
 	static struct {
-	    char *name;
+	    const char *name;
 	    Pixmap (*proc)(unsigned int *, unsigned int *);
 	} pmtab[] = {
 	    { TBPM_DOT,		CreateDotPixmap },
@@ -350,12 +350,11 @@ FindBitmap (char *name, unsigned *widthp, unsigned *heightp)
     pm = XmuLocateBitmapFile (ScreenOfDisplay(dpy, Scr->screen), bigname, NULL,
 			      0, (int *)widthp, (int *)heightp, &HotX, &HotY);
     if (pm == None && Scr->IconDirectory && bigname[0] != '/') {
-	if (bigname != name) free (bigname);
+	free (bigname);
 	/*
 	 * Attempt to find icon in old IconDirectory (now obsolete)
 	 */
-	bigname = (char *) malloc (strlen(name) + strlen(Scr->IconDirectory) +
-				   2);
+	bigname = malloc (strlen(name) + strlen(Scr->IconDirectory) + 2);
 	if (!bigname) {
 	    fprintf (stderr,
 		     "%s:  unable to allocate memory for \"%s/%s\"\n",
@@ -368,7 +367,7 @@ FindBitmap (char *name, unsigned *widthp, unsigned *heightp)
 	    pm = None;
 	}
     }
-    if (bigname != name) free (bigname);
+    free (bigname);
     if (pm == None) {
 	fprintf (stderr, "%s:  unable to find bitmap \"%s\"\n",
 		 ProgramName, name);
@@ -378,7 +377,7 @@ FindBitmap (char *name, unsigned *widthp, unsigned *heightp)
 }
 
 Pixmap
-GetBitmap (char *name)
+GetBitmap (const char *name)
 {
     return FindBitmap (name, &JunkWidth, &JunkHeight);
 }
@@ -395,7 +394,7 @@ InsertRGBColormap (Atom a, XStandardColormap *maps, int nmaps, Bool replace)
     }
 
     if (!sc) {				/* no existing, allocate new */
-	sc = (StdCmap *) malloc (sizeof (StdCmap));
+	sc = malloc (sizeof (StdCmap));
 	if (!sc) {
 	    fprintf (stderr, "%s:  unable to allocate %ld bytes for StdCmap\n",
 		     ProgramName, (unsigned long)sizeof (StdCmap));
@@ -404,7 +403,7 @@ InsertRGBColormap (Atom a, XStandardColormap *maps, int nmaps, Bool replace)
     }
 
     if (replace) {			/* just update contents */
-	if (sc->maps) XFree ((char *) maps);
+	if (sc->maps) XFree (maps);
 	if (sc == Scr->StdCmapInfo.mru) Scr->StdCmapInfo.mru = NULL;
     } else {				/* else appending */
 	sc->next = NULL;
@@ -433,7 +432,7 @@ RemoveRGBColormap (Atom a)
 	prev = sc;
     }
     if (sc) {				/* found one */
-	if (sc->maps) XFree ((char *) sc->maps);
+	if (sc->maps) XFree (sc->maps);
 	if (prev) prev->next = sc->next;
 	if (Scr->StdCmapInfo.head == sc) Scr->StdCmapInfo.head = sc->next;
 	if (Scr->StdCmapInfo.tail == sc) Scr->StdCmapInfo.tail = prev;
@@ -443,7 +442,7 @@ RemoveRGBColormap (Atom a)
 }
 
 void
-LocateStandardColormaps()
+LocateStandardColormaps(void)
 {
     Atom *atoms;
     int natoms;
@@ -459,12 +458,12 @@ LocateStandardColormaps()
 	    InsertRGBColormap (atoms[i], maps, nmaps, False);
 	}
     }
-    if (atoms) XFree ((char *) atoms);
+    if (atoms) XFree (atoms);
     return;
 }
 
 void
-GetColor(int kind, Pixel *what, char *name)
+GetColor(int kind, Pixel *what, const char *name)
 {
     XColor color, junkcolor;
     Status stat = 0;
@@ -542,7 +541,7 @@ GetColor(int kind, Pixel *what, char *name)
 }
 
 void
-GetColorValue(int kind, XColor *what, char *name)
+GetColorValue(int kind, XColor *what, const char *name)
 {
     XColor junkcolor;
     Colormap cmap = Scr->TwmRoot.cmaps.cwins[0]->colormap->c;
@@ -579,7 +578,7 @@ GetColorValue(int kind, XColor *what, char *name)
 void
 GetFont(MyFont *font)
 {
-    char *deffontname = "fixed";
+    const char *deffontname = "fixed";
     char **missing_charset_list_return;
     int missing_charset_count_return;
     char *def_string_return;
@@ -590,17 +589,13 @@ GetFont(MyFont *font)
     int ascent;
     int descent;
     int fnum;
-    char *basename2;
 
     if (use_fontset) {
 	if (font->fontset != NULL){
 	    XFreeFontSet(dpy, font->fontset);
 	}
 
-	basename2 = (char *)malloc(strlen(font->name) + 3);
-	if (basename2) sprintf(basename2, "%s,*", font->name);
-	else basename2 = font->name;
-	if( (font->fontset = XCreateFontSet(dpy, basename2,
+	if( (font->fontset = XCreateFontSet(dpy, font->name,
 					    &missing_charset_list_return,
 					    &missing_charset_count_return,
 					    &def_string_return)) == NULL) {
@@ -608,7 +603,6 @@ GetFont(MyFont *font)
 			 ProgramName, font->name);
 	    exit(1);
 	}
-	if (basename2 != font->name) free(basename2);
 	for(i=0; i<missing_charset_count_return; i++){
 	    printf("%s: warning: font for charset %s is lacking.\n",
 		   ProgramName, missing_charset_list_return[i]);
@@ -651,7 +645,7 @@ GetFont(MyFont *font)
 }
 
 int
-MyFont_TextWidth(MyFont *font, char *string, int len)
+MyFont_TextWidth(MyFont *font, const char *string, int len)
 {
     XRectangle ink_rect;
     XRectangle logical_rect;
@@ -666,7 +660,7 @@ MyFont_TextWidth(MyFont *font, char *string, int len)
 
 void
 MyFont_DrawImageString(Display *dpy, Drawable d, MyFont *font, GC gc,
-                       int x, int y, char *string, int len)
+                       int x, int y, const char *string, int len)
 {
     if (use_fontset) {
 	XmbDrawImageString(dpy, d, font->fontset, gc, x, y, string, len);
@@ -677,7 +671,7 @@ MyFont_DrawImageString(Display *dpy, Drawable d, MyFont *font, GC gc,
 
 void
 MyFont_DrawString(Display *dpy, Drawable d, MyFont *font, GC gc,
-                  int x, int y, char *string, int len)
+                  int x, int y, const char *string, int len)
 {
     if (use_fontset) {
 	XmbDrawString(dpy, d, font->fontset, gc, x, y, string, len);
